@@ -21,7 +21,8 @@ from PyQt5.QtCore import (
     QFile,
 )
 from . import __version__
-from .options import SakiaOptions
+from sakia.constants import GITLAB_RELEASES_API_URL, GITLAB_RELEASES_PAGE_URL
+from sakia.options import SakiaOptions
 from sakia.data.connectors import BmaConnector
 from sakia.services import (
     NetworkService,
@@ -309,40 +310,30 @@ class Application(QObject):
             async with aiohttp.ClientSession() as session:
                 async with async_timeout.timeout(10):
                     response = await session.get(
-                        "https://api.github.com/repos/duniter/sakia/releases",
+                        GITLAB_RELEASES_API_URL,
                         proxy=self.parameters.proxy(),
                     )
                     if response.status == 200:
                         releases = await response.json()
-                        latest = None
-                        for r in releases:
-                            if not latest:
-                                latest = r
-                            else:
-                                latest_date = datetime.datetime.strptime(
-                                    latest["published_at"], "%Y-%m-%dT%H:%M:%SZ"
-                                )
-                                date = datetime.datetime.strptime(
-                                    r["published_at"], "%Y-%m-%dT%H:%M:%SZ"
-                                )
-                                if latest_date < date:
-                                    latest = r
-                        latest_version = latest["tag_name"]
-                        version = (
-                            __version__ == latest_version,
-                            latest_version,
-                            latest["html_url"],
-                        )
-                        logging.debug("Found version: {0}".format(latest_version))
-                        logging.debug("Current version: {0}".format(__version__))
-                        self.available_version = version
+
+                        if len(releases) > 0:
+                            release = releases[0]
+                            latest_version = release["tag_name"]
+                            version = (
+                                __version__ == latest_version,
+                                latest_version,
+                                GITLAB_RELEASES_PAGE_URL,
+                            )
+                            logging.debug("Found version: {0}".format(latest_version))
+                            logging.debug("Current version: {0}".format(__version__))
+                            self.available_version = version
         except (
             aiohttp.ClientError,
             aiohttp.ServerDisconnectedError,
             asyncio.TimeoutError,
             socket.gaierror,
         ) as e:
-            self._logger.debug("Could not connect to github: {0}".format(str(e)))
+            self._logger.debug("Could not connect to gitlab: {0}".format(str(e)))
 
     def save_parameters(self, parameters):
         self.parameters = UserParametersFile.in_config_path(
