@@ -1,4 +1,3 @@
-import asyncio
 from PyQt5.QtWidgets import QDialog
 from PyQt5.QtCore import pyqtSignal, Qt, QElapsedTimer, QDateTime, QCoreApplication
 from .connection_cfg_uic import Ui_ConnectionConfigurationDialog
@@ -7,10 +6,10 @@ from duniterpy.key import SigningKey
 from duniterpy.key.scrypt_params import ScryptParams
 from math import ceil, log
 from sakia.gui.widgets import toast
-from sakia.decorators import asyncify
 from sakia.helpers import timestamp_to_dhms
 from sakia.gui.widgets.dialogs import dialog_async_exec, QAsyncMessageBox
-from sakia.constants import ROOT_SERVERS, G1_LICENSE
+from sakia.constants import G1_LICENSE
+from sakia.app import Application
 
 
 class ConnectionConfigView(QDialog, Ui_ConnectionConfigurationDialog):
@@ -20,11 +19,14 @@ class ConnectionConfigView(QDialog, Ui_ConnectionConfigurationDialog):
 
     values_changed = pyqtSignal()
 
-    def __init__(self, parent):
+    def __init__(self, parent, app: Application):
         """
-        Constructor
+        Init ConnectionConfigView
+        :param parent: Parent QObject
+        :param app: Application instance
         """
         super().__init__(parent)
+        self.app = app
         self.setupUi(self)
         self.last_speed = 0.1
         self.average_speed = 1
@@ -156,7 +158,7 @@ class ConnectionConfigView(QDialog, Ui_ConnectionConfigurationDialog):
         self.setWindowTitle(
             QCoreApplication.translate(
                 "ConnectionConfigView", "New sakia account on {0} network"
-            ).format(ROOT_SERVERS[currency]["display"])
+            ).format(self.app.root_servers[currency]["display"])
         )
 
     def action_show_pubkey(self):
