@@ -1,4 +1,4 @@
-from PyQt5.QtCore import QObject, QLocale, QDateTime
+from PyQt5.QtCore import QObject, QLocale, QDateTime, QCoreApplication
 from sakia.data.processors import ConnectionsProcessor
 import attr
 import math
@@ -37,15 +37,18 @@ class ToolbarModel(QObject):
         latest = self.app.available_version
         version_info = ""
         version_url = ""
+        url_text = ""
+
         if not latest[0]:
             version_info = "Latest release: {version}".format(version=latest[1])
             version_url = latest[2]
+            url_text = QCoreApplication.translate("ToolbarView", "Download page")
 
         new_version_text = """
             <p><b>{version_info}</b></p>
-            <p><a href={version_url}>Download link</a></p>
+            <p><a href={version_url}>{url_text}</a></p>
             """.format(
-            version_info=version_info, version_url=version_url
+            version_info=version_info, version_url=version_url, url_text=url_text
         )
         return """
         <h1>Sakia</h1>
