@@ -97,7 +97,6 @@ class ToolbarView(QFrame, Ui_SakiaToolbar):
         self.button_network.setIconSize(self.button_network.iconSize() * dpi_ratio())
         self.button_contacts.setIconSize(self.button_contacts.iconSize() * dpi_ratio())
         self.button_identity.setIconSize(self.button_identity.iconSize() * dpi_ratio())
-        self.button_explore.setIconSize(self.button_explore.iconSize() * dpi_ratio())
         self.toolbutton_menu.setIconSize(self.toolbutton_menu.iconSize() * dpi_ratio())
         self.button_network.setFixedHeight(
             self.button_network.height() * dpi_ratio() + 5 * dpi_ratio()
@@ -108,9 +107,6 @@ class ToolbarView(QFrame, Ui_SakiaToolbar):
         self.button_identity.setFixedHeight(
             self.button_identity.height() * dpi_ratio() + 5 * dpi_ratio()
         )
-        self.button_explore.setFixedHeight(
-            self.button_explore.height() * dpi_ratio() + 5 * dpi_ratio()
-        )
         self.toolbutton_menu.setFixedHeight(
             self.toolbutton_menu.height() * dpi_ratio() + 5 * dpi_ratio()
         )
