@@ -5,6 +5,7 @@ from PyQt5.QtWidgets import QMenu, QAction, QApplication, QMessageBox
 
 from duniterpy.constants import PUBKEY_REGEX
 from duniterpy.documents.crc_pubkey import CRCPubkey
+from duniterpy.grammars.output import Condition, SIG
 
 from sakia.app import Application
 from sakia.data.entities import Identity, Transaction, Dividend, Connection, Source
@@ -106,7 +107,7 @@ class ContextMenu(QObject):
             menu.qmenu.addAction(copy_selfcert)
 
     @staticmethod
-    def _add_transfer_actions(menu, transfer):
+    def _add_transfer_actions(menu, transfer: Transaction):
         """
         :param ContextMenu menu: the qmenu to add actions to
         :param Transfer transfer: the transfer
@@ -137,9 +138,18 @@ class ContextMenu(QObject):
         if transfer.conditions is not None or (
             transfer.pubkey in transfer.receivers and menu._app.parameters.expert_mode
         ):
-            # get source from conditions and transaction hash
+            conditions = (
+                transfer.conditions
+                if transfer.conditions
+                else Condition.token(SIG.token(transfer.pubkey)).compose(Condition())
+            )
+            # get source from transfer infos
             source = menu._app.sources_service.get_one(
-                identifier=transfer.sha_hash, conditions=transfer.conditions
+                currency=transfer.currency,
+                identifier=transfer.sha_hash,
+                conditions=conditions,
+                type=Source.TYPE_TRANSACTION,
+                pubkey=menu._connection.pubkey,
             )
             if source:
                 # add send as source menu
@@ -191,7 +201,9 @@ class ContextMenu(QObject):
         if menu._app.parameters.expert_mode:
             # get dividend source from block number and type
             source = menu._app.sources_service.get_one(
-                noffset=dividend.block_number, type=Source.TYPE_DIVIDEND
+                noffset=dividend.block_number,
+                type=Source.TYPE_DIVIDEND,
+                pubkey=menu._connection.pubkey,
             )
             if source:
                 # add send as source menu
