@@ -9,6 +9,8 @@ from PyQt5.QtCore import Qt, QObject, QCoreApplication
 from PyQt5.QtWidgets import QApplication, QMessageBox, QDialog, QPushButton, QLabel
 
 from duniterpy.api.errors import DuniterError
+
+from sakia.constants import GITLAB_NEW_ISSUE_PAGE_URL
 from sakia.helpers import single_instance_lock, cleanup_lock
 from quamash import QSelectorEventLoop
 from sakia.errors import NoPeerAvailable
@@ -129,7 +131,9 @@ def exception_message(log_lines, exc_info):
         QMessageBox.Critical,
         "Critical error",
         """A critical error occured. Select the details to display it.
-                  Please report it to <a href='https://github.com/duniter/sakia/issues/new/'>the developers github</a>""",
+                  Please report it to <a href='{}'>the developers Gitlab</a>""".format(
+            GITLAB_NEW_ISSUE_PAGE_URL
+        ),
         QMessageBox.Ok,
         QApplication.activeWindow(),
     )
@@ -162,6 +166,8 @@ def main():
     loop.set_exception_handler(async_exception_handler)
     # loop.set_debug(True)
     asyncio.set_event_loop(loop)
+    # Fix quamash https://github.com/harvimt/quamash/issues/123
+    asyncio.events._set_running_loop(loop)
 
     with loop:
         app = Application.startup(sys.argv, sakia, loop)
