@@ -112,8 +112,10 @@ class IdentitiesService(QObject):
                     blockstamp = BlockUID(ms["blockNumber"], ms["blockHash"])
                     membership_data = ms
             if membership_data:
-                identity.membership_timestamp = await self._blockchain_processor.timestamp(
-                    self.currency, blockstamp.number
+                identity.membership_timestamp = (
+                    await self._blockchain_processor.timestamp(
+                        self.currency, blockstamp.number
+                    )
                 )
                 identity.membership_buid = blockstamp
                 identity.membership_type = membership_data["membership"]
@@ -199,8 +201,10 @@ class IdentitiesService(QObject):
                         certified[cert] = certified_idty
                         # We save connections pubkeys
                         if self.is_identity_of_connection(identity):
-                            cert.timestamp = self._blockchain_processor.rounded_timestamp(
-                                self.currency, cert.block
+                            cert.timestamp = (
+                                self._blockchain_processor.rounded_timestamp(
+                                    self.currency, cert.block
+                                )
                             )
                             self._certs_processor.insert_or_update_certification(cert)
         except errors.DuniterError as e:
@@ -395,8 +399,10 @@ class IdentitiesService(QObject):
                         identity.blockstamp = block_uid(
                             identity_data["meta"]["timestamp"]
                         )
-                        identity.timestamp = self._blockchain_processor.rounded_timestamp(
-                            self.currency, identity.blockstamp.number
+                        identity.timestamp = (
+                            self._blockchain_processor.rounded_timestamp(
+                                self.currency, identity.blockstamp.number
+                            )
                         )
                         identity.outdistanced = identity_data["outdistanced"]
                         identity.written = identity_data["wasMember"]
